@@ -51,6 +51,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -80,11 +82,15 @@ class WordPress(
         :param rds_instance: The WordPress RDS.
         :param vpc: The WordPress VPC.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(WordPress.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WordPressProps(cluster=cluster, rds_instance=rds_instance, vpc=vpc)
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="endpoint")
     def endpoint(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "endpoint"))
@@ -109,6 +115,11 @@ class WordPressProps:
         :param rds_instance: The WordPress RDS.
         :param vpc: The WordPress VPC.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(WordPressProps.__init__)
+            check_type(argname="argument cluster", value=cluster, expected_type=type_hints["cluster"])
+            check_type(argname="argument rds_instance", value=rds_instance, expected_type=type_hints["rds_instance"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
         self._values: typing.Dict[str, typing.Any] = {}
         if cluster is not None:
             self._values["cluster"] = cluster
